@@ -45,6 +45,7 @@ struct memcached_st {
     bool is_purging:1;
     bool is_processing_input:1;
     bool is_time_for_rebuild:1;
+    bool not_used:1;
   } state;
 
   struct {
@@ -63,6 +64,8 @@ struct memcached_st {
     bool verify_key:1;
     bool tcp_keepalive:1;
     bool is_aes:1;
+    bool is_fetching_version:1;
+    bool not_used:1;
   } flags;
 
   memcached_server_distribution_t distribution;
@@ -71,8 +74,13 @@ struct memcached_st {
     unsigned int version;
   } server_info;
   uint32_t number_of_hosts;
-  memcached_server_st *servers;
-  memcached_server_st *last_disconnected_server;
+#ifdef __cplusplus
+  org::libmemcached::Instance* servers;
+  org::libmemcached::Instance* last_disconnected_server;
+#else
+  void *servers;
+  void *last_disconnected_server;
+#endif
   int32_t snd_timeout;
   int32_t rcv_timeout;
   uint32_t server_failure_limit;
@@ -92,11 +100,11 @@ struct memcached_st {
   memcached_result_st result;
 
   struct {
-    bool weighted;
+    bool weighted_;
     uint32_t continuum_count; // Ketama
     uint32_t continuum_points_counter; // Ketama
     time_t next_distribution_rebuild; // Ketama
-    memcached_continuum_item_st *continuum; // Ketama
+    struct memcached_continuum_item_st *continuum; // Ketama
   } ketama;
 
   struct memcached_virtual_bucket_t *virtual_bucket;
