@@ -49,6 +49,7 @@ using namespace libtest;
 
 #include <tests/libmemcached-1.0/parser.h>
 #include <tests/print.h>
+#include "libmemcached/instance.h"
 
 enum scanner_type_t
 {
@@ -187,6 +188,7 @@ scanner_variable_t test_number_options[]= {
 };
 
 scanner_variable_t test_boolean_options[]= {
+  { ARRAY,  make_scanner_string("--FETCH-VERSION"), scanner_string_null, NULL },
   { ARRAY,  make_scanner_string("--BINARY-PROTOCOL"), scanner_string_null, NULL },
   { ARRAY,  make_scanner_string("--BUFFER-REQUESTS"), scanner_string_null, NULL },
   { ARRAY,  make_scanner_string("--HASH-WITH-NAMESPACE"), scanner_string_null, NULL },
@@ -615,7 +617,7 @@ test_return_t random_statement_build_test(memcached_st*)
 }
 
 static memcached_return_t dump_server_information(const memcached_st *,
-                                                  const memcached_server_st *instance,
+                                                  memcached_server_instance_st instance,
                                                   void *)
 {
   if (strcmp(memcached_server_name(instance), "localhost")) 
@@ -664,7 +666,7 @@ struct socket_weight_t {
 };
 
 static memcached_return_t dump_socket_information(const memcached_st *,
-                                                  const memcached_server_st *instance,
+                                                  memcached_server_instance_st instance,
                                                   void *context)
 {
   socket_weight_t *check= (socket_weight_t *)context;
@@ -747,7 +749,9 @@ test_return_t regression_bug_71231153_connect(memcached_st *)
 test_return_t regression_bug_71231153_poll(memcached_st *)
 {
   if (libmemcached_util_ping("10.0.2.252", 0, NULL)) // If for whatever reason someone has a host at this address, skip
+  {
     return TEST_SKIPPED;
+  }
 
   { // Test the poll timeout, on a bad host we should get MEMCACHED_CONNECTION_FAILURE
     memcached_st *memc= memcached(test_literal_param("--SERVER=10.0.2.252 --POLL-TIMEOUT=0"));
