@@ -139,7 +139,7 @@ collection_st collection[] ={
 
 static void *world_create(server_startup_st& servers, test_return_t& error)
 {
-  if (HAVE_MEMCACHED_BINARY == 0)
+  if (libtest::has_memcached() == false)
   {
     error= TEST_SKIPPED;
     return NULL;
@@ -160,4 +160,3 @@ void get_world(Framework *world)
   world->collections(collection);
   world->create(world_create);
 }
-
